gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r28072 - in gnunet/src: include mesh


From: gnunet
Subject: [GNUnet-SVN] r28072 - in gnunet/src: include mesh
Date: Tue, 16 Jul 2013 02:00:16 +0200

Author: bartpolot
Date: 2013-07-16 02:00:16 +0200 (Tue, 16 Jul 2013)
New Revision: 28072

Modified:
   gnunet/src/include/gnunet_mesh_service.h
   gnunet/src/mesh/mesh_api.c
Log:
- use same options everywhere

Modified: gnunet/src/include/gnunet_mesh_service.h
===================================================================
--- gnunet/src/include/gnunet_mesh_service.h    2013-07-15 23:34:07 UTC (rev 
28071)
+++ gnunet/src/include/gnunet_mesh_service.h    2013-07-16 00:00:16 UTC (rev 
28072)
@@ -228,7 +228,7 @@
  * @param tunnel_ctx client's tunnel context to associate with the tunnel
  * @param peer peer identity the tunnel should go to
  * @param port Port number.
- * @param buffer Flag for buffering on relay nodes.
+ * @param nobuffer Flag for disabling buffering on relay nodes.
  * @param reliable Flag for end-to-end reliability.
  *
  * @return handle to the tunnel
@@ -238,7 +238,7 @@
                            void *tunnel_ctx,
                            const struct GNUNET_PeerIdentity *peer,
                            uint32_t port,
-                           int buffer,
+                           int nobuffer,
                            int reliable);
 
 

Modified: gnunet/src/mesh/mesh_api.c
===================================================================
--- gnunet/src/mesh/mesh_api.c  2013-07-15 23:34:07 UTC (rev 28071)
+++ gnunet/src/mesh/mesh_api.c  2013-07-16 00:00:16 UTC (rev 28072)
@@ -1409,7 +1409,7 @@
  * @param tunnel_ctx client's tunnel context to associate with the tunnel
  * @param peer peer identity the tunnel should go to
  * @param port Port number.
  * @param buffer Flag for buffering on relay nodes.
  * @param reliable Flag for end-to-end reliability.
  *
  * @return handle to the tunnel
@@ -1419,7 +1419,7 @@
                            void *tunnel_ctx,
                            const struct GNUNET_PeerIdentity *peer,
                            uint32_t port,
-                           int buffer,
+                           int nobuffer,
                            int reliable)
 {
   struct GNUNET_MESH_Tunnel *t;
@@ -1439,7 +1439,7 @@
   msg.opt = 0;
   if (GNUNET_YES == reliable)
     msg.opt |= GNUNET_MESH_OPTION_RELIABLE;
-  if (GNUNET_NO == buffer)
+  if (GNUNET_YES == nobuffer)
     msg.opt |= GNUNET_MESH_OPTION_NOBUFFER;
   msg.opt = htonl (msg.opt);
   t->allow_send = 0;
@@ -1409,7 +1409,7 @@
  * @param peer peer identity the tunnel should go to
  * @param port Port number.
- * @param buffer Flag for buffering on relay nodes.
+ * @param nobuffer Flag for disabling buffering on relay nodes.
  * @param reliable Flag for end-to-end reliability.
  *




reply via email to

[Prev in Thread] Current Thread [Next in Thread]